breed [investors investor]
breed [predictors predictor]
investors-own [demand]
predictors-own [owner condition action var actual-var fitness default active last-active best-predictor last-active-at]
globals [Ninvestors Npredictors Nmarketbits Nshares market-state r lambda theta p-u p T price-series volume-series dividend-series hree-price-series]

to setup
  ca
  reset-ticks
  set Ninvestors 25
  set Nshares Ninvestors
  set Npredictors 100
  set Nmarketbits 12
  set market-state []
  set price-series [100.]
  set volume-series [0.]
  set dividend-series [10.]
  set hree-price-series [100.]
  set r .1
  set lambda .5
  ifelse fast-learning?
  [set theta (1. / 75.)
   set p-u (1. / 250.)
   set p .1]
  [set theta (1. / 250.)
   set p-u (1. / 1000.)
   set p .3]
  set T 4000
  create-investors Ninvestors
  create-predictors Npredictors * Ninvestors

  ask investors [
    set demand 0
    set shape "person"
    set size 2
  ]

let an 0
let side sqrt Ninvestors
let step max-pxcor / side
let x 0
let y 0
while [an < Ninvestors]
  [  
    if x > (side - 1) * step 
                [set y y + step
                 set x 0       ]
    ask investor an
     [setxy x y]
    set x x + step
    set an an + 1 
  ]

  initialize-predictors
  
  
end

to initialize-predictors
  ;; create link to investor owner and initialize default variable
  ask predictors [
    set condition []
    set action []
    set actual-var 4.
    set var 4.
    set fitness 0.
    set owner (who mod Ninvestors)
    ifelse who < 2 * Ninvestors
    [set default TRUE]
    [set default FALSE]
    set last-active FALSE
    set last-active-at 0
    set best-predictor FALSE
  ]
    ;; initialization of non-default predictors
  ask predictors with [default = FALSE] [
    ;; initialize condition and fitness
    let i 0
    while [i < Nmarketbits] [
      ifelse random-float 1 < .9
      [set condition lput -1 condition]
      [
        ifelse random-float 1 < .5
        [set condition lput 1 condition]
        [set condition lput 0 condition]
      ]
      set i i + 1
    ]
    
    set fitness (- actual-var - 0.005 * (specificity condition))
    ;; initialize action
    set action list (.7 + random-float .5) (-10. + random-float 29.002)
    ]
  
  ;; initialization of default predictors
  ask predictors with [default = TRUE] [
      ;; initialize condition
      set condition n-values Nmarketbits [-1]
      ;; initialize fitness
      set fitness (- actual-var)
    ]
  ;; initialize action
  update-default-predictor
end

to update-default-predictor
  ask predictors with [default = TRUE] [
    let my-owner owner
    let a sum [item 0 action * (1. / actual-var)] of other predictors with [owner = my-owner]
    let b sum [item 1 action * (1. / actual-var)] of other predictors with [owner = my-owner]
    let c sum [1. / actual-var] of other predictors with [owner = my-owner]
    set action list (a / c) (b / c)
  ]
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; reporters and procedures for computation of market-state and market-state condition comparison
to-report moving-average [order]
    report mean sublist price-series (ticks - order) (ticks)
end

to-report market-state-comparison [value threshold]
  ifelse value > threshold
  [report 1]
  [report 0]
end

to generate-market-state
  let fundamental-bits map [market-state-comparison (last price-series * r / last dividend-series) ?] [.25 .5 .75 .875 1. 1.125]
  let technical-bits map [market-state-comparison last price-series (moving-average ?)] [5 10 100 500]
  let control-bits [1 0]
  set market-state (sentence fundamental-bits technical-bits control-bits)
end

to-report compare-market-state [this-condition]
  let i 0
  let flag FALSE
  while [i < Nmarketbits and flag = FALSE] [
    if item i this-condition != item i market-state and item i this-condition != -1 [set flag TRUE]
    set i (i + 1) 
  ]
  ifelse flag
  [report FALSE]
  [report TRUE]
end

;; reporter for trading and predictors' updating
to-report expectation [time this-action]
  report (item 0 this-action) * ((item time price-series) + (item time dividend-series)) + (item 1 this-action)
end

to-report specificity [this-condition]
  let counter 0
  foreach this-condition [
    if ? != -1 [set counter (counter + 1)]
  ]
  report counter
end

to-report tournament [pool]
  let candidate-1 one-of pool
  let candidate-2 one-of pool
  ifelse [fitness] of candidate-1 > [fitness] of candidate-2
  [report candidate-1]
  [report candidate-2]
end

to mutate 
  hatch-predictors 1 [
    ;; condition mutation
    let i 0
    while [i < Nmarketbits] [
      let bit (item i condition)
      if random-float 1. < 0.03 [
        if bit = 0 [
          ifelse random-float 1. < (2. / 3.)
          [set condition replace-item i condition -1]
          [set condition replace-item i condition 1]
        ]
        if bit = 1 [
          ifelse random-float 1. < (2. / 3.)
          [set condition replace-item i condition -1]
          [set condition replace-item i condition 0]
        ]
        if bit = -1 [
          ifelse random-float 1. < (1. / 3.)
          [set condition replace-item i condition -1]
          [ifelse random-float 1. < (1. / 2.)
            [set condition replace-item i condition 0]
            [set condition replace-item i condition 1]
          ]
        ]
      ]
      set i (i + 1)
    ]
    
    ;; action mutation
    if random-float 1. < 0.4 
    [ifelse random-float 1. < 0.5
      [set action list (.7 + random-float .5) (-10. + random-float 29.)]
      [set action list (.95 - 0.0025 + random-float 0.005 ) (4.5)]
    ]
    
    ;; other variables
    set fitness (- var - 0.005 * (specificity condition))
    set default FALSE
    set active FALSE
    set last-active ticks
  ]
end

to recombination [parent-1 parent-2]
  let parents turtle-set predictors with [who = [who] of parent-1 or who = [who] of parent-2] 
  let recombined-condition []
  let recombined-action []
  let recombined-var (mean ([var] of parents))
  let recombined-actual-var recombined-var
 
  
  ;; condition recombination
  let i 0
  while [i < Nmarketbits] [
    ifelse random-float 1. < .5
    [set recombined-condition lput [item i condition] of parent-1 recombined-condition]
    [set recombined-condition lput [item i condition] of parent-2 recombined-condition]
    set i (i + 1)
  ]
  
  ;; action recombination
  ifelse random-float 1. < (1. / 3.)
  [ifelse random-float 1. < .5
    [
      set recombined-action lput [item 0 action] of parent-1 recombined-action
      set recombined-action lput [item 1 action] of parent-2 recombined-action
    ]
    [
      set recombined-action lput [item 0 action] of parent-2 recombined-action
      set recombined-action lput [item 1 action] of parent-1 recombined-action
    ]
  ]
  [ifelse random-float 1. < .5
    [
      ifelse random-float 1. < .5
      [set recombined-action [action] of parent-1]
      [set recombined-action [action] of parent-2]
    ]
    [
      set recombined-action lput ((sum [(item 0 action) / var] of parents) / (sum [1. / var] of parents)) recombined-action
      set recombined-action lput ((sum [(item 1 action) / var] of parents) / (sum [1. / var] of parents)) recombined-action
    ]
  ]
  
  let recombined-fitness (- recombined-var - 0.005 * specificity recombined-condition)
  
  ;; initialization of recombined predictor
  set condition recombined-condition
  set action recombined-action
  set var recombined-var
  set fitness recombined-fitness
  set default FALSE
  set active FALSE
  set last-active ticks
  
end

to mutate-for-inactivity
  let bits-index []
  let i 0
  while [i < Nmarketbits] [
    if item i condition != -1 [set bits-index lput i bits-index]
    set i (i + 1)
  ]
  let j 0
  while [j < round (length(bits-index) / 4.)] [
    set condition replace-item (one-of bits-index) condition -1
    set j (j + 1)
  ]
end

    
  

to go
  tick
  ifelse ticks < 500
  [
    set dividend-series lput (10 + 0.95 * (last dividend-series - 10.) + random-normal 0 (sqrt 0.0743)) dividend-series 
    set price-series lput (last dividend-series / r) price-series
    let f (0.95 / (1 + r - 0.95))
    let g (1 + f) * ((1. / r) * (( 1 - 0.95) * 10. - lambda * 0.0743))
    set hree-price-series lput (f *(last dividend-series) + g) hree-price-series
    set volume-series lput 0. volume-series
  ]
  [
    ;; generate market state
    generate-market-state
    ;; dividend is posted
    set dividend-series lput (10 + 0.95 * (last dividend-series - 10.) + random-normal 0 (sqrt 0.0743)) dividend-series
    
    ask investors [
      let my-who who
      ask predictors with [owner = my-who] [set active compare-market-state condition]
      let active-predictors predictors with [owner = my-who and active = TRUE]
      let my-best-predictor first sort-by [[actual-var] of ?1 < [actual-var] of ?2] active-predictors
      ask my-best-predictor [set best-predictor TRUE]
      ]
    
    ;; price is posted
    let coefficient-1 sum [(item 0 action) / (lambda * var)] of predictors with [best-predictor = TRUE]
    let coefficient-2 sum [(item 1 action) / (lambda * var)] of predictors with [best-predictor = TRUE]
    let coefficient-3 sum [1. / (lambda * var)] of predictors with [best-predictor = TRUE]
    set price-series lput ((Nshares - last dividend-series * coefficient-1 - coefficient-2) / (coefficient-1 - (1. + r) * coefficient-3)) price-series
    
    let f (0.95 / (1 + r - 0.95))
    let g (1 + f) * ((1. / r) * (( 1 - 0.95) * 10. - lambda * 0.0743))
    set hree-price-series lput (f *(last dividend-series) + g) hree-price-series
    
    ask investors [
      let this-who who
      let this-demand last [((item 0 action)*(last price-series + last dividend-series) + (item 1 action) - (last price-series) * (1 + r)) / (lambda * var)] of predictors with [owner = this-who and best-predictor = TRUE]
      ifelse demand > this-demand [set color red] [set color green]
      set demand this-demand
      ]
    
    ;; updating predictors
    ask predictors with [last-active = TRUE] [
      let squared-err (last price-series + last dividend-series - (expectation (ticks - 1) action))^(2)
      if squared-err > 500.
      [set squared-err 500.]
      set actual-var (1. - theta) * actual-var + theta * squared-err
      set last-active FALSE
      set last-active-at ticks
  ]
  
    ask predictors with [active = TRUE] [
      set active FALSE
      set last-active TRUE
    ]
    
    update-default-predictor
    
    ;; genetic algorithm
    ask investors [
      if random-float 1. < p-u [
        ;; variance updating
        let my-who who
        ask predictors with [owner = my-who] [
          set var actual-var
          set fitness (- var - 0.005 * specificity condition)
        ]
        ;; elimination of 20% worst predictors
        let sorted-predictors-by-variance (sort-by [[fitness] of ?1 > [fitness] of ?2] predictors with [owner = my-who and default = FALSE])
        let worst-predictors sublist sorted-predictors-by-variance 0 20
        let elite-predictors sublist sorted-predictors-by-variance 20 99
        foreach worst-predictors [
          ask ? [die]
        ]
        ;; replacement of dead predictors by mutation or recombination
        let i 0
        while [i < 20] [
          ifelse random-float 1. > p
          [ 
            ask tournament elite-predictors [mutate]
          ]
          [
            ask tournament elite-predictors [hatch-predictors 1 [recombination (myself) (tournament elite-predictors)]]
          ] 
          set i (i + 1) 
         ]
      ]
    ]
    
    ;; generalization
    ask predictors [
        if ticks - last-active-at > T [
          mutate-for-inactivity
        ]
      ]
]
end
@#$#@#$#@
GRAPHICS-WINDOW
234
10
673
470
-1
-1
13.0
1
10
1
1
1
0
0
0
1
0
32
0
32
0
0
1
ticks
30.0

BUTTON
9
13
82
46
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
684
22
1238
448
Price
NIL
NIL
0.0
0.0
1.0E-5
150.0
true
true
"set price-series [100]\nset hree-price-series [100]" ""
PENS
"Price" 1.0 0 -7500403 true "" "if ticks > 500 [plot last price-series]"
"HREE-Price" 1.0 0 -2674135 true "" "if ticks > 500 [plot last hree-price-series]"
"Difference" 1.0 0 -14070903 true "" "if ticks > 500 [plot last hree-price-series - last price-series + 10]"

BUTTON
93
13
156
46
Go!
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
4
53
159
86
fast-learning?
fast-learning?
0
1
-1000

@#$#@#$#@
## WHAT IS IT?

This is a NetLogo implementation of the Santa Fe Institute Artifical Stock Market, first proposed by Arthur, Holland, LeBaron, Palmer and Tayler in "Asset Pricing Under Endogenous Expectations in an Artificial Stock Market", 1996.

## HOW IT WORKS

Agents trade on the basis of heterogeneous and endogeneous expectations that evolve in time through a genetic algorithm, selecting the market predictors that performed best and mutating or recombining the worst.

## HOW TO USE IT

Let the market evolve for a considerable amount of time to allow agents to learn and for trascients to die out (in LeBaron, "Time Series Properties of an Artificial Stock Market", 1998, a stabilizing period of 250,000 ticks is suggested).
In the graph are plotted the Price generated by the market, a benchmark HREE-Price (Homogenous Rational Expectation Equilibrium Price) and their (re-scaled) Difference at any time for comparison.
The fast-learning? switch allows to control the speed of the genetic algorithm, switching between settings of slow and fast learning.

## THINGS TO NOTICE

The Price generated by the market is systematically lower than the HREE-Price, predicted by the rational utility-maximization theory under homogeous expectations. This is due to the fact that the use of heterogenous expectations leads to higher uncertainty in the market.
Furthermore the difference between the two prices shows periods of clustering volatility, marking times at which the market is relatively calm and times at which it is sensibly volatile.

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)

## COPYRIGHT

Copyright 2014 Gabriele Visentin.

![CC BY-NC-SA 4.0](https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png)

Creative Commons Licence
This work by Gabriele Visentin is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.  To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/legalcode
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.5
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
